@@ -1,7 +1,7 @@
-from collections import Counter
 from collections.abc import Iterable
 from contextlib import suppress
 import copy
+from enum import IntEnum
 from functools import partial
 import sys
 import weakref
@@ -41,13 +41,13 @@ _default_annotation_kwargs = dict(
 )
 _default_annotation_positions = [
     dict(position=(-15, 15), anncoords="offset points",
-         ha="right", va="bottom"),
+         horizontalalignment="right", verticalalignment="bottom"),
     dict(position=(15, 15), anncoords="offset points",
-         ha="left", va="bottom"),
+         horizontalalignment="left", verticalalignment="bottom"),
     dict(position=(15, -15), anncoords="offset points",
-         ha="left", va="top"),
+         horizontalalignment="left", verticalalignment="top"),
     dict(position=(-15, -15), anncoords="offset points",
-         ha="right", va="top"),
+         horizontalalignment="right", verticalalignment="top"),
 ]
 _default_highlight_kwargs = dict(
     # Only the kwargs corresponding to properties of the artist will be passed.
@@ -66,6 +66,17 @@ class _MarkedStr(str):
     """A string subclass solely for marking purposes."""
 
 
+def _mouse_event_matches(event, spec):
+    """
+    Return whether a mouse event "matches" an event spec, which is either a
+    single mouse button, or a mapping matched against ``vars(event)``, e.g.
+    ``{"button": 1, "key": "control"}``.
+    """
+    if isinstance(spec, int):
+        spec = {"button": spec}
+    return all(getattr(event, k) == v for k, v in spec.items())
+
+
 def _get_rounded_intersection_area(bbox_1, bbox_2):
     """Compute the intersection area between two bboxes rounded to 8 digits."""
     # The rounding allows sorting areas without floating point issues.
@@ -99,6 +110,10 @@ def _reassigned_axes_event(event, ax):
     return event
 
 
+class HoverMode(IntEnum):
+    NoHover, Persistent, Transient = range(3)
+
+
 class Cursor:
     """
     A cursor for selecting Matplotlib artists.
@@ -136,22 +151,30 @@ class Cursor:
         artists : List[Artist]
             A list of artists that can be selected by this cursor.
 
-        multiple : bool, optional
-            Whether multiple artists can be "on" at the same time (defaults to
-            False).
+        multiple : bool, default: False
+            Whether multiple artists can be "on" at the same time.
 
-        highlight : bool, optional
+        highlight : bool, default: False
             Whether to also highlight the selected artist.  If so,
             "highlighter" artists will be placed as the first item in the
             :attr:`extras` attribute of the `Selection`.
 
-        hover : bool, optional
+        hover : `HoverMode`, default: False
             Whether to select artists upon hovering instead of by clicking.
             (Hovering over an artist while a button is pressed will not trigger
             a selection; right clicking on an annotation will still remove it.)
+            Possible values are
+
+            - False, alias `HoverMode.NoHover`: hovering is inactive.
+            - True, alias `HoverMode.Persistent`: hovering is active;
+              annotations remain in place even after the mouse moves away from
+              the artist (until another artist is selected, if *multiple* is
+              False.
+            - 2, alias `HoverMode.Transient`: hovering is active; annotations
+              are removed as soon as the mouse moves away from the artist.
 
         bindings : dict, optional
-            A mapping of button and keybindings to actions.  Valid entries are:
+            A mapping of actions to button and keybindings.  Valid keys are:
 
             ================ ==================================================
             'select'         mouse button to select an artist
@@ -175,16 +198,21 @@ class Cursor:
             ================ ==================================================
 
             Missing entries will be set to the defaults.  In order to not
-            assign any binding to an action, set it to ``None``.
+            assign any binding to an action, set it to ``None``.  Modifier keys
+            (or other event properties) can be set for mouse button bindings by
+            passing them as e.g. ``{"button": 1, "key": "control"}``.
 
-        annotation_kwargs : dict, optional
+        annotation_kwargs : dict, default: {}
             Keyword argments passed to the `annotate
             <matplotlib.axes.Axes.annotate>` call.
 
         annotation_positions : List[dict], optional
             List of positions tried by the annotation positioning algorithm.
+            The default is to try four positions, 15 points to the NW, NE, SE,
+            and SW from the selected point; annotations that stay within the
+            axes are preferred.
 
-        highlight_kwargs : dict, optional
+        highlight_kwargs : dict, default: {}
             Keyword arguments used to create a highlighted artist.
         """
 
@@ -204,6 +232,7 @@ class Cursor:
         self._last_auto_position = None
         self._callbacks = {"add": [], "remove": []}
 
+        self._hover = hover
         connect_pairs = [("key_press_event", self._on_key_press)]
         if hover:
             connect_pairs += [
@@ -223,11 +252,15 @@ class Cursor:
         if unknown_bindings:
             raise ValueError("Unknown binding(s): {}".format(
                 ", ".join(sorted(unknown_bindings))))
-        duplicate_bindings = [
-            k for k, v in Counter(bindings.values()).items() if v > 1]
-        if duplicate_bindings:
-            raise ValueError("Duplicate binding(s): {}".format(
-                ", ".join(sorted(map(str, duplicate_bindings)))))
+        bindings_items = list(bindings.items())
+        for i in range(len(bindings)):
+            action, key = bindings_items[i]
+            for j in range(i):
+                other_action, other_key = bindings_items[j]
+                if key == other_key:
+                    raise ValueError(
+                        f"Duplicate bindings: {key} is used for "
+                        f"{other_action} and for {action}")
         self.bindings = bindings
 
         self.annotation_kwargs = (
@@ -334,8 +367,10 @@ class Cursor:
         ann = axes.annotate(
             _pick_info.get_ann_text(*pi), xy=pi.target,
             xytext=(np.nan, np.nan),
-            ha=_MarkedStr("center"), va=_MarkedStr("center"),
+            horizontalalignment=_MarkedStr("center"),
+            verticalalignment=_MarkedStr("center"),
             visible=self.visible,
+            zorder=np.inf,
             **self.annotation_kwargs)
         ann.draggable(use_blit=not self._multiple)
         extras = []
@@ -371,12 +406,14 @@ class Cursor:
             ann.set(**self.annotation_positions[auto_position])
             self._last_auto_position = auto_position
         else:
-            if isinstance(ann.get_ha(), _MarkedStr):
-                ann.set_ha({-1: "right", 0: "center", 1: "left"}[
-                    np.sign(np.nan_to_num(ann.xyann[0]))])
-            if isinstance(ann.get_va(), _MarkedStr):
-                ann.set_va({-1: "top", 0: "center", 1: "bottom"}[
-                    np.sign(np.nan_to_num(ann.xyann[1]))])
+            if isinstance(ann.get_horizontalalignment(), _MarkedStr):
+                ann.set_horizontalalignment(
+                    {-1: "right", 0: "center", 1: "left"}[
+                        np.sign(np.nan_to_num(ann.xyann[0]))])
+            if isinstance(ann.get_verticalalignment(), _MarkedStr):
+                ann.set_verticalalignment(
+                    {-1: "top", 0: "center", 1: "bottom"}[
+                        np.sign(np.nan_to_num(ann.xyann[1]))])
 
         if (extras
                 or len(self.selections) > 1 and not self._multiple
@@ -390,8 +427,7 @@ class Cursor:
             # Fast path, only needed if the annotation has not been immediately
             # removed.
             figure.draw_artist(ann)
-            # Explicit argument needed on MacOSX backend.
-            figure.canvas.blit(figure.bbox)
+            figure.canvas.blit()
         # Removal comes after addition so that the fast blitting path works.
         if not self._multiple:
             for sel in self.selections[:-1]:
@@ -442,6 +478,14 @@ class Cursor:
 
             # Make label non-draggable:
             lambda sel: sel.draggable(False)
+
+        Note that when a single event causes both the removal of an "old"
+        selection and the addition of a "new" one (typically, clicking on an
+        artist when another one is selected, or hovering -- both assuming that
+        ``multiple=False``), the "add" callback is called *first*.  This allows
+        it, in particular, to "cancel" the addition (by immediately removing
+        the "new" selection) and thus avoid removing the "old" selection.
+        However, this call order may change in a future release.
         """
         if event not in self._callbacks:
             raise ValueError(f"{event!r} is not a valid cursor event")
@@ -481,20 +525,20 @@ class Cursor:
 
     def _nonhover_handler(self, event):
         if event.name == "button_press_event":
-            if event.button == self.bindings["select"]:
-                self._on_select_button_press(event)
-            if event.button == self.bindings["deselect"]:
-                self._on_deselect_button_press(event)
+            if _mouse_event_matches(event, self.bindings["select"]):
+                self._on_select_event(event)
+            if _mouse_event_matches(event, self.bindings["deselect"]):
+                self._on_deselect_event(event)
 
     def _hover_handler(self, event):
         if event.name == "motion_notify_event" and event.button is None:
             # Filter away events where the mouse is pressed, in particular to
             # avoid conflicts between hover and draggable.
-            self._on_select_button_press(event)
+            self._on_select_event(event)
         elif (event.name == "button_press_event"
-              and event.button == self.bindings["deselect"]):
+              and _mouse_event_matches(event, self.bindings["deselect"])):
             # Still allow removing the annotation by right clicking.
-            self._on_deselect_button_press(event)
+            self._on_deselect_event(event)
 
     def _filter_mouse_event(self, event):
         # Accept the event iff we are enabled, and either
@@ -505,7 +549,7 @@ class Cursor:
         return (self.enabled
                 and event.canvas.widgetlock.locked() == event.dblclick)
 
-    def _on_select_button_press(self, event):
+    def _on_select_event(self, event):
         if not self._filter_mouse_event(event):
             return
         # Work around lack of support for twinned axes.
@@ -515,18 +559,30 @@ class Cursor:
         for artist in self.artists:
             if (artist.axes is None  # Removed or figure-level artist.
                     or event.canvas is not artist.figure.canvas
+                    or not artist.get_visible()
                     or not artist.axes.contains(event)[0]):  # Cropped by axes.
                 continue
             pi = _pick_info.compute_pick(artist, per_axes_event[artist.axes])
-            if pi and not any((pi.artist, tuple(pi.target))
-                              == (other.artist, tuple(other.target))
-                              for other in self._selections):
+            if pi:
                 pis.append(pi)
-        if not pis:
-            return
-        self.add_selection(min(pis, key=lambda pi: pi.dist))
+        # The any() check avoids picking an already selected artist at the same
+        # point, as likely the user is just dragging it.  We check this here
+        # rather than not adding the pick_info to pis at all, because in
+        # transient hover mode, selections should be cleared out only when no
+        # candidate picks (including such duplicates) exist at all.
+        pi = min((pi for pi in pis
+                  if not any((pi.artist, tuple(pi.target))
+                             == (other.artist, tuple(other.target))
+                             for other in self._selections)),
+                 key=lambda pi: pi.dist, default=None)
+        if pi:
+            self.add_selection(pi)
+        elif not pis and self._hover == HoverMode.Transient:
+            for sel in self.selections:
+                if event.canvas is sel.annotation.figure.canvas:
+                    self.remove_selection(sel)
 
-    def _on_deselect_button_press(self, event):
+    def _on_deselect_event(self, event):
         if not self._filter_mouse_event(event):
             return
         for sel in self.selections[::-1]:  # LIFO.
