@@ -93,6 +93,9 @@ class ContainerArtist:
     figure = property(lambda self: _artist_in_container(self.container).figure)
     axes = property(lambda self: _artist_in_container(self.container).axes)
 
+    def get_visible(self):
+        return True  # For lack of anything better.
+
 
 class AttrArray(np.ndarray):
     """An array subclass that can store additional attributes."""
@@ -287,20 +290,14 @@ def _(artist, event):
         ds = np.hypot(*(xy - data_screen_xy).T)
         try:
             argmin = np.nanargmin(ds)
-            dmin = ds[argmin]
-        except (ValueError, IndexError):
-            # numpy 1.7.0's `nanargmin([nan])` returns nan, so
-            # `ds[argmin]` raises IndexError.  In later versions of numpy,
-            # `nanargmin([nan])` raises ValueError (the release notes for 1.8.0
-            # are incorrect on this topic).
+        except ValueError:  # Raised by nanargmin([nan]).
             pass
         else:
-            # More precise than transforming back.
             target = _with_attrs(
-                _untransform(
+                _untransform(  # More precise than transforming back.
                     data_xy[argmin], data_screen_xy[argmin], artist.axes),
                 index=argmin)
-            sels.append(Selection(artist, target, dmin, None, None))
+            sels.append(Selection(artist, target, ds[argmin], None, None))
     # If lines are visible, find the closest projection.
     if (artist.get_linestyle() not in ["None", "none", " ", "", None]
             and len(artist.get_xydata()) > 1):
@@ -332,13 +329,15 @@ def _(artist, event):
 @compute_pick.register(PatchCollection)
 @compute_pick.register(PathCollection)
 def _(artist, event):
-    # Use the C implementation to prune the list of segments.
-    contains, info = artist.contains(event)
-    if not contains:
-        return
     offsets = artist.get_offsets()
     paths = artist.get_paths()
     if _is_scatter(artist):
+        # Use the C implementation to prune the list of segments -- but only
+        # for scatter plots as that implementation is inconsistent with Line2D
+        # for segment-like collections (matplotlib/matplotlib#17279).
+        contains, info = artist.contains(event)
+        if not contains:
+            return
         inds = info["ind"]
         offsets = artist.get_offsets()[inds]
         offsets_screen = artist.get_offset_transform().transform(offsets)
@@ -350,23 +349,21 @@ def _(artist, event):
         return Selection(artist, target, ds[argmin], None, None)
     else:
         # Note that this won't select implicitly closed paths.
-        sels = [
+        sels = [*filter(None, [
             _compute_projection_pick(
                 artist,
                 Affine2D().translate(*offsets[ind % len(offsets)])
                 .transform_path(paths[ind % len(paths)]),
                 (event.x, event.y))
-            for ind in info["ind"]]
-        sel, index = min(
-            ((sel, info["ind"][idx]) for idx, sel in enumerate(sels) if sel),
-            key=lambda sel_idx: sel_idx[0].dist,
-            default=(None, None))
-        if sel:
-            sel = sel._replace(artist=artist)
-            sel.target.index = (index, sel.target.index)
-            if (isinstance(artist, PatchCollection)
-                    and sel.dist >= PATCH_PICKRADIUS):
-                sel = None
+            for ind in range(max(len(offsets), len(paths)))])]
+        if not sels:
+            return None
+        idx = min(range(len(sels)), key=lambda idx: sels[idx].dist)
+        sel = sels[idx]
+        if sel.dist >= artist.get_pickradius():
+            return None
+        sel = sel._replace(artist=artist)
+        sel.target.index = (idx, sel.target.index)
         return sel
 
 
@@ -464,14 +461,16 @@ def _(container, event):
     sel = compute_pick(container.markerline, event)
     if sel:
         return sel
-    idx_sel = min(filter(lambda idx_sel: idx_sel[1] is not None,
-                         ((idx, compute_pick(line, event))
-                          for idx, line in enumerate(container.stemlines))),
-                  key=lambda idx_sel: idx_sel[1].dist, default=None)
-    if idx_sel:
-        idx, _ = idx_sel
+    if not isinstance(container.stemlines, LineCollection):
+        warnings.warn("Only stem plots created with use_line_collection=True "
+                      "are supported.")
+        return
+    sel = compute_pick(container.stemlines, event)
+    if sel:
+        idx, _ = sel.target.index
         target = _with_attrs(
-            container.stemlines[idx].get_xydata()[-1], index=idx)
+            container.stemlines.get_segments()[idx][-1],
+            index=sel.target.index)
         return Selection(container, target, 0, None, None)
 
 
@@ -520,7 +519,7 @@ def get_ann_text(sel):
     classes follow.
     """
     warnings.warn(
-        f"Annotation support for {type(sel.artist).__name__} is missing")
+        f"Annotation support for {type(sel.artist).__name__} is missing.")
     return ""
 
 
@@ -632,10 +631,16 @@ def _(sel):
                          for e in err]
                 # We'd normally want to check err.sum() == 0, but that can run
                 # into fp inaccuracies.
-                if len({s.lstrip("+-") for s in err_s}) == 1:
+                signs = "+-\N{MINUS SIGN}"
+                if len({s.lstrip(signs) for s in err_s}) == 1:
                     repl = rf"\1=$\2\\pm{err_s[1]}$\3"
                 else:
-                    err_s = [("+" if not s.startswith(("+", "-")) else "") + s
+                    # Replacing unicode minus by ascii minus don't change the
+                    # rendering as the string is mathtext, but allows keeping
+                    # the same tests across Matplotlib versions that use
+                    # unicode minus and those that don't.
+                    err_s = [("+" if not s.startswith(tuple(signs)) else "")
+                             + s.replace("\N{MINUS SIGN}", "-")
                              for s in err_s]
                     repl = r"\1=$\2_{%s}^{%s}$\3" % tuple(err_s)
                 ann_text = re.sub(f"({dir})=(.*)(\n?)", repl, ann_text)
@@ -747,7 +752,7 @@ def make_highlight(sel, *, highlight_kwargs):
     classes follow.
     """
     warnings.warn(
-        f"Highlight support for {type(sel.artist).__name__} is missing")
+        f"Highlight support for {type(sel.artist).__name__} is missing.")
 
 
 def _set_valid_props(artist, kwargs):
