@@ -13,7 +13,7 @@ from matplotlib import pyplot as plt
 from matplotlib.axes import Axes
 from matplotlib.backend_bases import KeyEvent, MouseEvent
 import mplcursors
-from mplcursors import _pick_info, Selection
+from mplcursors import _pick_info, Selection, HoverMode
 import numpy as np
 import pytest
 
@@ -38,16 +38,12 @@ def ax(fig):
 
 @pytest.fixture(autouse=True)
 def cleanup():
-    for fig in map(plt.figure, plt.get_fignums()):
-        fig.clf()
-
-
-@pytest.fixture(autouse=True)
-def cleanup_warnings():
-    try:
-        yield
-    finally:
-        mplcursors.__warningregistry__ = {}
+    with mpl.rc_context({"axes.unicode_minus": False}):
+        try:
+            yield
+        finally:
+            mplcursors.__warningregistry__ = {}
+            plt.close("all")
 
 
 def _internal_warnings(record):
@@ -124,8 +120,8 @@ def test_line(ax, plotter):
     # On the line.
     _process_event("__mouse_click__", ax, (.1, .4), 1)
     assert len(cursor.selections) == len(ax.texts) == 1
-    assert (_parse_annotation(cursor.selections[0], "foo\nx=(.*)\ny=(.*)")
-            == approx((.1, .4)))
+    assert _parse_annotation(
+        cursor.selections[0], "foo\nx=(.*)\ny=(.*)") == approx((.1, .4))
     # Not removing it.
     _process_event("__mouse_click__", ax, (0, 1), 3)
     assert len(cursor.selections) == len(ax.texts) == 1
@@ -133,8 +129,8 @@ def test_line(ax, plotter):
     artist.set_label(None)
     _process_event("__mouse_click__", ax, (.6, .9), 1)
     assert len(cursor.selections) == len(ax.texts) == 2
-    assert (_parse_annotation(cursor.selections[1], "x=(.*)\ny=(.*)")
-            == approx((.6, .9)))
+    assert _parse_annotation(
+        cursor.selections[1], "x=(.*)\ny=(.*)") == approx((.6, .9))
     # Remove both of them (first removing the second one, to test
     # `Selection.__eq__` -- otherwise it is bypassed as `list.remove`
     # checks identity first).
@@ -163,7 +159,8 @@ def test_scatter_text(ax):
     ax.scatter([0, 1], [0, 1], c=[2, 3])
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (0, 0), 1)
-    assert cursor.selections[0].annotation.get_text() == "x=0\ny=0\n[2]"
+    assert _parse_annotation(
+        cursor.selections[0], "x=(.*)\ny=(.*)\n\[(.*)\]") == (0, 0, 2)
 
 
 def test_steps_index():
@@ -260,25 +257,25 @@ def test_image(ax, origin):
     # Annotation text includes image value.
     _process_event("__mouse_click__", ax, (.25, .25), 1)
     sel, = cursor.selections
-    assert (_parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]")
-            == approx((.25, .25)))
+    assert _parse_annotation(
+        sel, r"x=(.*)\ny=(.*)\n\[0\]") == approx((.25, .25))
     # Moving around.
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
-    assert sel.annotation.get_text() == "x=1\ny=0\n[1]"
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[1\]") == (1, 0)
     assert array[sel.target.index] == 1
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
-    assert sel.annotation.get_text() == "x=0\ny=0\n[0]"
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
     assert array[sel.target.index] == 0
     _process_event("key_press_event", ax, (.123, .456), "shift+up")
     sel, = cursor.selections
-    assert (sel.annotation.get_text()
-            == {"upper": "x=0\ny=2\n[4]", "lower": "x=0\ny=1\n[2]"}[origin])
+    assert (_parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[(.*)\]")
+            == {"upper": (0, 2, 4), "lower": (0, 1, 2)}[origin])
     assert array[sel.target.index] == {"upper": 4, "lower": 2}[origin]
     _process_event("key_press_event", ax, (.123, .456), "shift+down")
     sel, = cursor.selections
-    assert sel.annotation.get_text() == "x=0\ny=0\n[0]"
+    assert _parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0\]") == (0, 0)
     assert array[sel.target.index] == 0
 
     cursor = mplcursors.cursor()
@@ -295,12 +292,12 @@ def test_image_rgb(ax):
     cursor = mplcursors.cursor()
     _process_event("__mouse_click__", ax, (0, 0), 1)
     sel, = cursor.selections
-    assert (_parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0.1, 0.2, 0.3\]")
-            == approx((0, 0)))
+    assert _parse_annotation(
+        sel, r"x=(.*)\ny=(.*)\n\[0.1, 0.2, 0.3\]") == approx((0, 0))
     _process_event("key_press_event", ax, (.123, .456), "shift+right")
     sel, = cursor.selections
-    assert (_parse_annotation(sel, r"x=(.*)\ny=(.*)\n\[0.4, 0.5, 0.6\]")
-            == approx((1, 0)))
+    assert _parse_annotation(
+        sel, r"x=(.*)\ny=(.*)\n\[0.4, 0.5, 0.6\]") == approx((1, 0))
 
 
 def test_image_subclass(ax):
@@ -315,7 +312,8 @@ def test_image_subclass(ax):
 def test_linecollection(ax):
     ax.eventplot([0, 1])
     cursor = mplcursors.cursor()
-    _process_event("__mouse_click__", ax, (0, .5), 1)
+    _process_event("__mouse_click__", ax, (0, 0), 1)
+    _process_event("__mouse_click__", ax, (.5, 1), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (0, 1), 1)
     assert cursor.selections[0].target.index == approx((0, .5))
@@ -339,7 +337,8 @@ def test_quiver_and_barbs(ax, plotter):
     _process_event("__mouse_click__", ax, (.5, 0), 1)
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (1, 0), 1)
-    assert cursor.selections[0].annotation.get_text() == "x=1\ny=0\n(1, 1)"
+    assert _parse_annotation(
+        cursor.selections[0], r"x=(.*)\ny=(.*)\n\(1, 1\)") == (1, 0)
 
 
 @pytest.mark.parametrize("plotter,order",
@@ -363,14 +362,17 @@ def test_errorbar(ax):
     assert len(cursor.selections) == 0
     _process_event("__mouse_click__", ax, (.5, .5), 1)
     assert cursor.selections[0].target == approx((.5, .5))
-    assert (_parse_annotation(cursor.selections[0], "x=(.*)\ny=(.*)")
-            == approx((.5, .5)))
+    assert _parse_annotation(
+        cursor.selections[0], "x=(.*)\ny=(.*)") == approx((.5, .5))
     _process_event("__mouse_click__", ax, (0, 1), 1)
     assert cursor.selections[0].target == approx((0, 0))
-    assert cursor.selections[0].annotation.get_text() == "x=0\ny=$0\\pm1$"
+    assert _parse_annotation(
+        cursor.selections[0], r"x=(.*)\ny=\$(.*)\\pm(.*)\$") == (0, 0, 1)
     _process_event("__mouse_click__", ax, (1, 2), 1)
-    assert cursor.selections[0].target == approx((1, 1))
-    assert cursor.selections[0].annotation.get_text() == "x=1\ny=$1_{-1}^{+2}$"
+    sel, = cursor.selections
+    assert sel.target == approx((1, 1))
+    assert _parse_annotation(
+        sel, r"x=(.*)\ny=\$(.*)_\{(.*)\}\^\{(.*)\}\$") == (1, 1, -1, 2)
 
 
 def test_dataless_errorbar(ax):
@@ -384,7 +386,7 @@ def test_dataless_errorbar(ax):
 
 def test_stem(ax):
     with pytest.warns(None):  # stem use_line_collection API change.
-        ax.stem([1, 2, 3])
+        ax.stem([1, 2, 3], use_line_collection=True)
     cursor = mplcursors.cursor()
     assert len(cursor.artists) == 1
     _process_event("__mouse_click__", ax, (.5, .5), 1)
@@ -455,14 +457,18 @@ def test_move(ax, plotter):
     assert cursor.selections[0].target.index == 0
 
 
-def test_hover(ax):
+@pytest.mark.parametrize(
+    "hover", [True, HoverMode.Persistent, 2, HoverMode.Transient])
+def test_hover(ax, hover):
     l1, = ax.plot([0, 1])
     l2, = ax.plot([1, 2])
-    cursor = mplcursors.cursor(hover=True)
+    cursor = mplcursors.cursor(hover=hover)
     _process_event("motion_notify_event", ax, (.5, .5), 1)
     assert len(cursor.selections) == 0  # No trigger if mouse button pressed.
     _process_event("motion_notify_event", ax, (.5, .5))
     assert cursor.selections[0].artist == l1
+    _process_event("motion_notify_event", ax, (.5, 1))
+    assert bool(cursor.selections) == (hover == HoverMode.Persistent)
     _process_event("motion_notify_event", ax, (.5, 1.5))
     assert cursor.selections[0].artist == l2
 
